@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+"""Custom Errors
+"""
 
 
 class SemanticReleaseBaseError(Exception):
@@ -19,3 +21,7 @@ class GitError(SemanticReleaseBaseError):
 
 class CiVerificationError(SemanticReleaseBaseError):
     pass
+
+
+class HvcsRepoParseError(SemanticReleaseBaseError):
+    pass
