@@ -4,16 +4,11 @@ import collections
 import re
 from typing import Tuple
 
-re_breaking = re.compile('BREAKING[ -]CHANGE: (.*)')
+re_breaking = re.compile("BREAKING[ -]CHANGE: (.*)")
 
 
 ParsedCommit = collections.namedtuple(
-    'ParsedCommit', [
-        'bump',
-        'type',
-        'scope',
-        'descriptions'
-    ]
+    "ParsedCommit", ["bump", "type", "scope", "descriptions"]
 )
 
 
@@ -26,10 +21,10 @@ def parse_text_block(text: str) -> Tuple[str, str]:
     :return: A tuple with body and footer,
     where footer is defined as the last paragraph.
     """
-    body, footer = '', ''
+    body, footer = "", ""
     if text:
-        body = text.split('\n\n')[0]
-        if len(text.split('\n\n')) == 2:
-            footer = text.split('\n\n')[1]
+        body = text.split("\n\n")[0]
+        if len(text.split("\n\n")) == 2:
+            footer = text.split("\n\n")[1]
 
-    return body.replace('\n', ' '), footer.replace('\n', ' ')
+    return body.replace("\n", " "), footer.replace("\n", " ")
