@@ -1,15 +1,22 @@
 """Helper for using Twine to upload to PyPI.
 """
+import logging
+
 from invoke import run
 
 from semantic_release import ImproperConfigurationError
 
+from .helpers import LoggedFunction
 
+logger = logging.getLogger(__name__)
+
+
+@LoggedFunction(logger)
 def upload_to_pypi(
-        path: str = 'dist',
-        username: str = None,
-        password: str = None,
-        skip_existing: bool = False
+    path: str = "dist",
+    username: str = None,
+    password: str = None,
+    skip_existing: bool = False,
 ):
     """Upload wheels to PyPI with Twine.
 
@@ -22,13 +29,10 @@ def upload_to_pypi(
         (Only valid when uploading to PyPI. Other implementations may not support this.)
     """
     if username is None or password is None or username == "" or password == "":
-        raise ImproperConfigurationError('Missing credentials for uploading')
+        raise ImproperConfigurationError("Missing credentials for uploading")
 
     run(
         "twine upload -u '{}' -p '{}' {} \"{}/*\"".format(
-            username,
-            password,
-            '--skip-existing' if skip_existing else '',
-            path
+            username, password, "--skip-existing" if skip_existing else "", path
         )
     )
